@@ -1,17 +1,6 @@
-#define __GNOME_FONT_C__
-
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2000-2001 Ximian Inc. and authors
- *
- *  Authors:
- *    Jody Goldberg <jody@ximian.com>
- *    Miguel de Icaza <miguel@ximian.com>
- *    Lauris Kaplinski <lauris@ximian.com>
- *    Christopher James Lahey <clahey@ximian.com>
- *    Michael Meeks <michael@ximian.com>
- *    Morten Welinder <terra@diku.dk>
- *
- *  GnomeFont - basic user visible handle to scaled typeface
+ *  gnome-font.c: basic user visible handle to scaled typeface
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public License
@@ -26,8 +15,20 @@
  *  You should have received a copy of the GNU Library General Public
  *  License along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *  Authors:
+ *    Jody Goldberg <jody@ximian.com>
+ *    Miguel de Icaza <miguel@ximian.com>
+ *    Lauris Kaplinski <lauris@ximian.com>
+ *    Christopher James Lahey <clahey@ximian.com>
+ *    Michael Meeks <michael@ximian.com>
+ *    Morten Welinder <terra@diku.dk>
+ *
+ *  Copyright (C) 2000-2001 Ximian Inc. and authors
  */
 
+#define __GNOME_FONT_C__
+
 #include <math.h>
 
 #include <stdlib.h>
@@ -237,7 +238,7 @@ gnome_font_get_prop (GObject *o, guint id, GValue *value, GParamSpec *pspec)
 	}
 }
 
-static GnomeFont *
+GnomeFont *
 gnome_font_face_get_font_full (GnomeFontFace *face, gdouble size, gdouble *affine)
 {
 	GnomeFont *font;
