@@ -45,8 +45,8 @@ G_BEGIN_DECLS
  *   - do printing
  *   gnome_print_config_unref ();
  *
- * In addition to printer specific data, it can store some more
- * generic data, that application may, or may not be interested in,
+ * In addition to printer specific information, it can store some more
+ * generic data, that application may, or may not, be interested in,
  * like page layout and margins.
  *
  * IMPORTANT
@@ -54,7 +54,7 @@ G_BEGIN_DECLS
  * Paper/Page size has been broken into different configuration
  * values.
  * Paper size or PhysicaSize referes strictly to the
- * real-world paper size in printer, similarly PhysicalOrinetation
+ * real-world paper size in printer, similarly PhysicalOrientation
  * marks, which paper side goes first into printer input tray.
  * Page size or LogicaSize refers to imaging area available to
  * application. This can conincide with physical paper size,
@@ -78,8 +78,24 @@ G_BEGIN_DECLS
  * Also - only GnomePrintMaster parses layouts and rearranges
  * printout. Plain print contexts are one step lower-level, and
  * transfer printout directly to specified Physicalpage. You
- * are safe to use these, if you are 100% sure, you do not
- * want to allow multipage layouts from your application.
+ * are safe to use these, if you are 100% sure that you do not
+ * want to allow multipage layouts and automatic feed orinetation
+ * compensation.
+ *
+ * ALSO
+ *
+ * Depending on key, its value can not be trivial. Most importantly
+ * paper dimensions are given as metric strings (i.e. '210mm', '8in')
+ * Consult with individual key descriptions about the format used.
+ *
+ * Matrixes are specified as transform (a0 a1 a2 a3 a4 a5), and used
+ *
+ * X' = X * A0 + Y * A2 + A4
+ * Y' = X * A1 + Y * A3 + A5
+ *
+ * But be careful with orientation matrixes, as A4 and A5 values are
+ * specified as fraction of target size in given dimension - i.e.
+ * they can be either width or height, dpending on rotation used.
  *
  * 14/12/2001
  * Lauris Kaplinski
@@ -97,9 +113,15 @@ GnomePrintConfig *gnome_print_config_default (void);
 
 GnomePrintConfig *gnome_print_config_ref (GnomePrintConfig *config);
 GnomePrintConfig *gnome_print_config_unref (GnomePrintConfig *config);
+GnomePrintConfig *gnome_print_config_dup (GnomePrintConfig *config);
 
 /*
  * Get/Set key value pairs
+ *
+ * All methods except gnome_print_config_get return TRUE on sucess (given
+ * key exists and/or its value can be changed to new value), FALSE otherwise.
+ * gnome_print_config_get just returns NULL, if given key does not exist.
+ *
  */
 
 guchar *gnome_print_config_get (GnomePrintConfig *config, const guchar *key);
@@ -124,8 +146,8 @@ gboolean gnome_print_config_set_length (GnomePrintConfig *config, const guchar *
  *
  * NB - this is NOT necessarily the actual page size you want to use in application
  * NB - If using multipage layouts, actual size is calculated from paper size,
- *      orientation and layout.
- * 
+ *      page orientation and layout.
+ *
  */
 
 #define GNOME_PRINT_KEY_PAPER_SIZE "Settings.Output.Media.PhysicalSize" /* Paper name, such as A4 or Letter */
@@ -141,12 +163,12 @@ gboolean gnome_print_config_set_length (GnomePrintConfig *config, const guchar *
 /* Just a reminder - application is only interested in logical orientation */
 #define GNOME_PRINT_KEY_ORIENTATION GNOME_PRINT_KEY_PAGE_ORIENTATION
 
-#define GNOME_PRINT_KEY_LAYOUT "Settings.Document.Page.Layout" /* Id of layout */
+#define GNOME_PRINT_KEY_LAYOUT "Settings.Document.Page.Layout" /* Id of layout ('Plain' is always no-special-layout) */
 #define GNOME_PRINT_KEY_LAYOUT_WIDTH "Settings.Document.Page.Layout.Width" /* Double value */
 #define GNOME_PRINT_KEY_LAYOUT_HEIGHT "Settings.Document.Page.Layout.Height" /* Double value */
 
 /* Master resolution, i.e. ink dots for color printer RGB resolution is usually smaller */
-#define GNOME_PRINT_KEY_RESOLUTION "Settings.Output.Resolution" /* String value, like 300x300 */
+#define GNOME_PRINT_KEY_RESOLUTION "Settings.Output.Resolution" /* String value, like 300x300 or 300dpi */
 #define GNOME_PRINT_KEY_RESOLUTION_DPI "Settings.Output.Resolution.DPI" /* Numeric value, like 300, if meaningful */
 #define GNOME_PRINT_KEY_RESOLUTION_DPI_X "Settings.Output.Resolution.DPI.X" /* Numeric value */
 #define GNOME_PRINT_KEY_RESOLUTION_DPI_Y "Settings.Output.Resolution.DPI.Y" /* Numeric value */
@@ -156,6 +178,7 @@ gboolean gnome_print_config_set_length (GnomePrintConfig *config, const guchar *
 #define GNOME_PRINT_KEY_COLLATE "Settings.Output.Job.Collate" /* Boolean (true|yes|1 false|no|0) */
 
 /* These are ignored by libgnomeprint, but you may want to get/set/inspect these */
+/* Libgnomeprintui uses these for displaying margin symbols */
 #define GNOME_PRINT_KEY_PAGE_MARGIN_LEFT "Settings.Document.Page.Margins.Left" /* Length, i.e. use conversion */
 #define GNOME_PRINT_KEY_PAGE_MARGIN_RIGHT "Settings.Document.Page.Margins.Right" /* Length, i.e. use conversion */
 #define GNOME_PRINT_KEY_PAGE_MARGIN_TOP "Settings.Document.Page.Margins.Top" /* Length, i.e. use conversion */
@@ -163,11 +186,17 @@ gboolean gnome_print_config_set_length (GnomePrintConfig *config, const guchar *
 
 /* These are ignored by libgnomeprint, and you most probably cannot change these too */
 /* Also - these are relative to ACTUAL PAGE IN PRINTER - not physicalpage */
+/* Libgnomeprintui uses these for displaying margin symbols */
 #define GNOME_PRINT_KEY_PAPER_MARGIN_LEFT "Settings.Output.Media.Margins.Left" /* Length, i.e. use conversion */
 #define GNOME_PRINT_KEY_PAPER_MARGIN_RIGHT "Settings.Output.Media.Margins.Right" /* Length, i.e. use conversion */
 #define GNOME_PRINT_KEY_PAPER_MARGIN_TOP "Settings.Output.Media.Margins.Top" /* Length, i.e. use conversion */
 #define GNOME_PRINT_KEY_PAPER_MARGIN_BOTTOM "Settings.Output.Media.Margins.Bottom" /* Length, i.e. use conversion */
 
+/* More handy keys */
+#define GNOME_PRINT_KEY_OUTPUT_FILENAME "Settings.Transport.Backend.FileName" /* Filename used when printing to file. Don't assume that if
+																 it isn't NULL printing to file is disabled it can contain
+																 a filename and not print to file	
+															    */
 G_END_DECLS
 
 #endif
