@@ -1,7 +1,6 @@
-#define __GNOME_PRINT_MASTER_C__
-
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  A system print interface.
+ *  gnome-print-master.c: A system print interface.
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public License
@@ -24,6 +23,8 @@
  *  Copyright (C) 2000-2001 Ximian Inc.
  */
 
+#define __GNOME_PRINT_MASTER_C__
+
 #include <math.h>
 #include <string.h>
 #include <stdlib.h>
@@ -38,7 +39,7 @@
 #include "gnome-print-multipage.h"
 #include "gnome-print-master-private.h"
 
-#define GPM_VERBOSE
+#define noGPM_VERBOSE
 
 typedef struct _GPMPrivate GPMPrivate;
 
@@ -1104,7 +1105,9 @@ gpm_parse_transform (guchar *str, gdouble *transform)
 	}
 
 	memcpy (transform, t, 6 * sizeof (gdouble));
+#if 0	
 	PRINT_AFFINE ("Got affine:", transform);
+#endif	
 
 	return TRUE;
 }
